@@ -1,13 +1,16 @@
 import os
 import io
-import unittest
 import unittest.mock
 
-from mcstasscript.helper.component_reader import ComponentInfo
 from mcstasscript.helper.component_reader import ComponentReader
 
 
 def setup_component_reader():
+    """
+    Sets up a component_reader instance with dummy mcstas
+    installation located in the tests directory
+    """
+
     THIS_DIR = os.path.dirname(os.path.abspath(__file__))
     dummy_path = os.path.join(THIS_DIR, "dummy_mcstas")
 
@@ -20,7 +23,13 @@ def setup_component_reader():
 
     return component_reader
 
+
 def setup_component_reader_input_path():
+    """
+    Sets up a component_reader instance with dummy mcstas
+    installation located in the tests directory, and specifies
+    a input_path which is also located in the test directory.
+    """
     THIS_DIR = os.path.dirname(os.path.abspath(__file__))
     dummy_path = os.path.join(THIS_DIR, "dummy_mcstas")
     input_path = os.path.join(THIS_DIR, "test_input_folder")
@@ -40,16 +49,17 @@ class TestComponentReader(unittest.TestCase):
     """
     Testing the ComponenReader class. As this class reads information
     from McStas, a dummy McStas install is made in the test folder to
-    avoid the test results changeing with updates of McStas.
+    avoid the test results changing with updates of McStas.
     """
 
     @unittest.mock.patch("sys.stdout", new_callable=io.StringIO)
     def test_ComponentReader_init_overwrite_message(self, mock_stdout):
         """
         Test that ComponentReader reports overwritten components
+        Here using default input path, which is current folder
         """
 
-        component_reader = setup_component_reader()
+        setup_component_reader()
 
         message = ("The following components are found in the work_directory "
                    + "/ input_path:\n     test_for_reading.comp\n"
@@ -62,9 +72,10 @@ class TestComponentReader(unittest.TestCase):
     def test_ComponentReader_init_overwrite_message_input(self, mock_stdout):
         """
         Test that ComponentReader reports overwritten components
+        Here using user defined input path, a directory in tests
         """
 
-        component_reader = setup_component_reader_input_path()
+        setup_component_reader_input_path()
 
         message = ("The following components are found in the work_directory "
                    + "/ input_path:\n     test_for_structure.comp\n"
@@ -103,27 +114,31 @@ class TestComponentReader(unittest.TestCase):
         self.assertEqual(n_components_found, 3)
 
         expected_path = os.path.join(THIS_DIR, "test_for_reading.comp")
-        self.assertIn("test_for_reading", component_reader.component_path)
-        self.assertEqual(component_reader.component_path["test_for_reading"],
-                         expected_path)
-        self.assertEqual(component_reader.component_category["test_for_reading"],
-                         "Work directory")
+        path = component_reader.component_path["test_for_reading"]
+        self.assertEqual(path, expected_path)
+
+        category = component_reader.component_category["test_for_reading"]
+        self.assertEqual(category, "Work directory")
 
         expected_path = os.path.join(dummy_path, "misc",
                                      "test_for_structure.comp")
         self.assertIn("test_for_structure", component_reader.component_path)
-        self.assertEqual(component_reader.component_path["test_for_structure"],
-                         expected_path)
-        self.assertEqual(component_reader.component_category["test_for_structure"],
-                         "misc")
 
+        path = component_reader.component_path["test_for_structure"]
+        self.assertEqual(path, expected_path)
+
+        category = component_reader.component_category["test_for_structure"]
+        self.assertEqual(category, "misc")
+
+        self.assertIn("test_for_structure2", component_reader.component_path)
+
+        path = component_reader.component_path["test_for_structure2"]
         expected_path = os.path.join(dummy_path, "sources",
                                      "test_for_structure2.comp")
-        self.assertIn("test_for_structure2", component_reader.component_path)
-        self.assertEqual(component_reader.component_path["test_for_structure2"],
-                         expected_path)
-        self.assertEqual(component_reader.component_category["test_for_structure2"],
-                         "sources")
+        self.assertEqual(path, expected_path)
+
+        category = component_reader.component_category["test_for_structure2"]
+        self.assertEqual(category, "sources")
 
     @unittest.mock.patch("sys.stdout", new_callable=io.StringIO)
     def test_ComponentReader_init_component_paths_input(self, mock_stdout):
@@ -142,29 +157,34 @@ class TestComponentReader(unittest.TestCase):
         n_components_found = len(component_reader.component_path)
         self.assertEqual(n_components_found, 3)
 
+        self.assertIn("test_for_reading", component_reader.component_path)
+
         expected_path = os.path.join(dummy_path, "misc",
                                      "test_for_reading.comp")
-        self.assertIn("test_for_reading", component_reader.component_path)
-        self.assertEqual(component_reader.component_path["test_for_reading"],
-                         expected_path)
-        self.assertEqual(component_reader.component_category["test_for_reading"],
-                         "misc")
+        path = component_reader.component_path["test_for_reading"]
+        self.assertEqual(path, expected_path)
+
+        category = component_reader.component_category["test_for_reading"]
+        self.assertEqual(category, "misc")
 
         expected_path = os.path.join(input_path, "test_for_structure.comp")
         self.assertIn("test_for_structure", component_reader.component_path)
-        self.assertEqual(component_reader.component_path["test_for_structure"],
-                         expected_path)
-        self.assertEqual(component_reader.component_category["test_for_structure"],
-                         "Work directory")
 
+        path = component_reader.component_path["test_for_structure"]
+        self.assertEqual(path, expected_path)
 
+        category = component_reader.component_category["test_for_structure"]
+        self.assertEqual(category, "Work directory")
+
+        self.assertIn("test_for_structure2", component_reader.component_path)
+
+        path = component_reader.component_path["test_for_structure2"]
         expected_path = os.path.join(dummy_path, "sources",
                                      "test_for_structure2.comp")
-        self.assertIn("test_for_structure2", component_reader.component_path)
-        self.assertEqual(component_reader.component_path["test_for_structure2"],
-                         expected_path)
-        self.assertEqual(component_reader.component_category["test_for_structure2"],
-                         "sources")
+        self.assertEqual(path, expected_path)
+
+        category = component_reader.component_category["test_for_structure2"]
+        self.assertEqual(category, "sources")
 
     @unittest.mock.patch("sys.stdout", new_callable=io.StringIO)
     def test_ComponentReader_init_categories(self, mock_stdout):
@@ -320,7 +340,7 @@ class TestComponentReader(unittest.TestCase):
         component_reader = setup_component_reader()
 
         with self.assertRaises(NameError):
-            CompInfo = component_reader.read_name("no_such_comp")
+            component_reader.read_name("no_such_comp")
 
     @unittest.mock.patch("sys.stdout", new_callable=io.StringIO)
     def test_ComponentReader_read_name_success(self, mock_stdout):
@@ -466,7 +486,7 @@ class TestComponentReader(unittest.TestCase):
     @unittest.mock.patch("sys.stdout", new_callable=io.StringIO)
     def test_ComponentReader_read_component_int(self, mock_stdout):
         """
-        Test that a integer parameter is read correctly when reading a
+        Test that a integer parameter is read correctly when reading an
         component file.
         Has default, is int type (comments and unit checked already)
         """
@@ -517,50 +537,6 @@ class TestComponentReader(unittest.TestCase):
         self.assertNotIn("test_string", CompInfo.parameter_units)
         # Have already tested units are read
 
-    @unittest.mock.patch("sys.stdout", new_callable=io.StringIO)
-    def test_ComponentReader_line_start_long(self, mock_stdout):
-        """
-        Helper function that should return true when certain string is
-        the start of another string.
-
-        """
-
-        component_reader = setup_component_reader()
-
-        test_string = "monkey wants banana"
-
-        return_val = component_reader.line_starts_with(test_string, "mo")
-        self.assertIsInstance(return_val, bool)
-        self.assertTrue(return_val)
-
-        return_val = component_reader.line_starts_with(test_string, "on")
-        self.assertIsInstance(return_val, bool)
-        self.assertFalse(return_val)
-
-    @unittest.mock.patch("sys.stdout", new_callable=io.StringIO)
-    def test_ComponentReader_line_start_short(self, mock_stdout):
-        """
-        Helper function that should return true when certain string is
-        the start of another string. Here checked with short test_string
-
-        """
-
-        component_reader = setup_component_reader()
-
-        test_string = "m"
-
-        return_val = component_reader.line_starts_with(test_string, "m")
-        self.assertIsInstance(return_val, bool)
-        self.assertTrue(return_val)
-
-        return_val = component_reader.line_starts_with(test_string, "mo")
-        self.assertIsInstance(return_val, bool)
-        self.assertFalse(return_val)
-
-        return_val = component_reader.line_starts_with(test_string, "on")
-        self.assertIsInstance(return_val, bool)
-        self.assertFalse(return_val)
-
 
 if __name__ == '__main__':
     unittest.main()
