@@ -21,6 +21,7 @@ def get_dummy_MetaData_1d():
 
     return meta_data
 
+
 def get_dummy_McStasData_1d():
     meta_data = get_dummy_MetaData_1d()
 
@@ -31,6 +32,7 @@ def get_dummy_McStasData_1d():
 
     return McStasData(meta_data, intensity, error, ncount, xaxis=axis)
 
+
 def get_dummy_MetaData_2d():
     meta_data = McStasMetaData()
     meta_data.component_name = "test a component"
@@ -42,6 +44,7 @@ def get_dummy_MetaData_2d():
 
     return meta_data
 
+
 def get_dummy_McStasData_2d():
     meta_data = get_dummy_MetaData_2d()
 
@@ -237,7 +240,7 @@ class TestPlotterHelpers(unittest.TestCase):
         """
 
         dummy_data = get_dummy_McStasData_2d()
-        dummy_data.Intensity[2,2] = 0
+        dummy_data.Intensity[2, 2] = 0
         dummy_data.set_plot_options(log=True)
         found_min, found_max = _find_min_max_I(dummy_data)
 
@@ -286,7 +289,7 @@ class TestPlotterHelpers(unittest.TestCase):
         """
 
         dummy_data = get_dummy_McStasData_2d()
-        dummy_data.Intensity[2,2] = 10**6
+        dummy_data.Intensity[2, 2] = 10**6
         dummy_data.set_plot_options(log=True, orders_of_mag=3)
         found_min, found_max = _find_min_max_I(dummy_data)
 
@@ -303,8 +306,8 @@ class TestPlotterHelpers(unittest.TestCase):
         """
 
         dummy_data = get_dummy_McStasData_2d()
-        dummy_data.Intensity[2,2] = 10**6
-        dummy_data.Intensity[2,3] = 0
+        dummy_data.Intensity[2, 2] = 10**6
+        dummy_data.Intensity[2, 3] = 0
         dummy_data.set_plot_options(log=True, orders_of_mag=3)
         found_min, found_max = _find_min_max_I(dummy_data)
 
@@ -394,7 +397,7 @@ class TestPlotterHelpers(unittest.TestCase):
 
         test_value = {"log": True, "orders_of_mag": 15,
                       "cut_min": 0.25, "cut_max": 0.8,
-                      "colormap": "hot", "show_colorbar": "False",
+                      "colormap": "hot", "show_colorbar": False,
                       "x_limit_multiplier": 2.8, "y_limit_multiplier": 0.8}
 
         for option in known_plot:
@@ -407,23 +410,32 @@ class TestPlotterHelpers(unittest.TestCase):
             default_value = defaults[kw_option]
 
             dummy_data1 = get_dummy_McStasData_2d()
-            dummy_data2 = get_dummy_McStasData_2d()
+            data1_value = dummy_data1.plot_options.__getattribute__(kw_option)
+            self.assertEqual(data1_value, default_value)
 
-            self.assertEqual(dummy_data1.plot_options.__getattribute__(kw_option), default_value)
-            self.assertEqual(dummy_data2.plot_options.__getattribute__(kw_option), default_value)
+            dummy_data2 = get_dummy_McStasData_2d()
+            data2_value = dummy_data2.plot_options.__getattribute__(kw_option)
+            self.assertEqual(data2_value, default_value)
 
             data_list = [dummy_data1, dummy_data2]
 
             set_value = test_value[kw_option]
             given_option = {option: set_value}
             _handle_kwargs(data_list, **given_option)
-            self.assertEqual(dummy_data1.plot_options.__getattribute__(kw_option), set_value)
-            self.assertEqual(dummy_data2.plot_options.__getattribute__(kw_option), set_value)
+
+            data1_value = dummy_data1.plot_options.__getattribute__(kw_option)
+            self.assertEqual(data1_value, set_value)
+
+            data2_value = dummy_data2.plot_options.__getattribute__(kw_option)
+            self.assertEqual(data2_value, set_value)
 
             given_option = {option: [set_value, default_value]}
             _handle_kwargs(data_list, **given_option)
-            self.assertEqual(dummy_data1.plot_options.__getattribute__(kw_option), set_value)
-            self.assertEqual(dummy_data2.plot_options.__getattribute__(kw_option), default_value)
+
+            data_1_value = dummy_data1.plot_options.__getattribute__(kw_option)
+            self.assertEqual(data_1_value, set_value)
+            data_2_value = dummy_data2.plot_options.__getattribute__(kw_option)
+            self.assertEqual(data_2_value, default_value)
 
     def test_handle_kwargs_left_lim(self):
         """
@@ -541,8 +553,8 @@ class TestPlotterHelpers(unittest.TestCase):
         """
 
         dummy_data = get_dummy_McStasData_2d()
-        retrived_figsize, data_list = _handle_kwargs(dummy_data, figsize=(5,9))
-        self.assertEqual(retrived_figsize, (5, 9))
+        found_figsize, data_list = _handle_kwargs(dummy_data, figsize=(5, 9))
+        self.assertEqual(found_figsize, (5, 9))
 
     def test_handle_kwargs_figsize_list(self):
         """
@@ -551,8 +563,8 @@ class TestPlotterHelpers(unittest.TestCase):
         """
 
         dummy_data = get_dummy_McStasData_2d()
-        retrived_figsize, data_list = _handle_kwargs(dummy_data, figsize=[5,9])
-        self.assertEqual(retrived_figsize, (5, 9))
+        found_figsize, data_list = _handle_kwargs(dummy_data, figsize=[5, 9])
+        self.assertEqual(found_figsize, (5, 9))
 
     def test_handle_kwargs_single_element_to_list(self):
         """
@@ -607,4 +619,4 @@ class TestPlotterHelpers(unittest.TestCase):
         dummy_data = get_dummy_McStasData_2d()
 
         fig, ax0 = plt.subplots()
-        _plot_fig_ax(dummy_data, fig, ax0, log=True)
\ No newline at end of file
+        _plot_fig_ax(dummy_data, fig, ax0, log=True)
